@@ -31,9 +31,9 @@ scenarios_home="${home}/scenarios"
 num_of_testcases=
 
 container_image_version="1.0.0"
-base_image_java="adoptopenjdk/openjdk8:alpine"
+base_image_java="eclipse-temurin:8-jdk"
 base_image_tomcat="tomcat:8.5-jdk8-openjdk"
-jacoco_version="${JACOCO_VERSION:-0.8.6}"
+jacoco_version="${JACOCO_VERSION:-0.8.8}"
 
 os="$(uname)"
 
@@ -148,6 +148,14 @@ agent_home_selector() {
     _agent_home=${target_agent_home}
 }
 
+remove_dir() {
+    dir=$1
+    if [[ "${os}" == "Darwin" ]]; then
+        find ${dir} -type d -exec chmod -a "$(whoami) deny delete" {} \;
+    fi
+    rm -rf $dir
+}
+
 start_stamp=`date +%s`
 parse_commandline "$@"
 
@@ -257,7 +265,7 @@ do
     bash ${case_work_base}/scenario.sh $debug_mode 1>${case_work_logs_dir}/${testcase_name}.log
     status=$?
     if [[ $status == 0 ]]; then
-        [[ -z $debug_mode ]] && rm -rf ${case_work_base}
+        [[ -z $debug_mode ]] && remove_dir ${case_work_base}
     else
         exitWithMessage "Testcase ${testcase_name} failed!"
     fi
